HtmlPageLoaderElement class

Base class for HTML elements.

Implemented types

Constructors

HtmlPageLoaderElement({SyncFn externalSyncFn = noOpExecuteSyncedFn})
HtmlPageLoaderElement.createFromElement(Element? _cachedElement, {SyncFn externalSyncFn = noOpExecuteSyncedFn})

Properties

attributes → PageLoaderAttributes
Attributes associated with this element.
no setteroverride
classes → List<String>
CSS classes associated with this element.
no setteroverride
computedStyle → PageLoaderAttributes
CSS properties of this element after applying the active stylesheets and resolving any basic computation, such as converting a percentage into an absolute length.
no setteroverride
context → dynamic
The context of this PageLoaderElement. This should only be used if this API does not provide desired functionality; otherwise usage should be avoided.
no setteroverride
contextSync → dynamic
Same as context.
no setteroverride
displayed → bool
Whether this element is displayed based on "display" style.
no setteroverride
elements → List<Element>
no setter
exists → bool
Whether this element exists on the page.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique ID to identify the element.
no setteroverride
innerText → String
The inner content of this element.
no setteroverride
isFocused → bool
Whether this element is focused.
no setteroverride
listeners → List<PageLoaderListener>
Gets registered listeners.
no setteroverride
name → String
The tag name of the node represented by this element.
no setteroverride
offset → Rectangle<num>
The offset of this element relative to its parent.
no setteroverride
properties → PageLoaderAttributes
Attributes associated with this element.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seleniumAttributes → PageLoaderAttributes
Attributes associated with this element.
no setteroverride
shadowRoot → PageLoaderElement
The shadow root hosted by this element.
no setteroverride
shadowRootChildren → List<PageLoaderElement>
The children of the shadow root hosted by this element.
no setteroverride
style → PageLoaderAttributes
This element's inline style attributes.
no setteroverride
syncFn → SyncFn
final
utils → PageUtils
Returns an instance of PageUtils.
no setteroverride
visibleText → String
Visible text within this element.
no setteroverride

Methods

addCheckers(List<Checker> checkers) → void
Adds additional Checkers to the list already maintained by the element.
override
addListeners(List<PageLoaderListener> listeners) → void
Adds listeners to element.
override
blur() → Future<Null>
Blurs the element (= lose focus).
override
byTag(String tagName) → PageLoaderElement
Finds PageLoaderElement from this source by tag.
override
clear({bool focusBefore = true, bool blurAfter = true}) → Future<Null>
Note: all elements below here should remain asynchronous to allow component tests to function properly. Clears the text of this element, if possible (e.g. for text fields).
override
click({ClickOption? clickOption}) → Future<Null>
Clicks on the element with clickOption. clickOption is only used for HTML.
override
clickOutside() → Future<void>
Clicks outside of the current element.
override
createElement(Finder finder, List<Filter> filters, List<Checker> checkers) → HtmlPageLoaderElement
Creates a new element based on the current context plus the passed Finder, Filters, and Checkers.
override
createIterable(Finder finder, List<Filter> filters, List<Checker> checkers) → HtmlPageElementIterable
Creates a new iterable based on the current context plus the passed Finder, Filters, and Checkers.
override
createList(Finder finder, List<Filter> filter, List<Checker> checkers) → List<PageLoaderElement>
Create a new list using the current element as the parent context.
override
dispatchCustomEvent(String name, {Object? detail}) → Future<void>
Dispatches the eventName custom event on this element.
override
dispatchEvent(Event event) → bool
Dispatches an html event from _single.
focus() → Future<Null>
Focuses the element.
override
getBoundingClientRect() → Rectangle<num>
The smallest bounding rectangle that encompasses this element's padding, scrollbar, and border.
override
getElementsByCss(String selector) → List<PageLoaderElement>
Returns the elements within this element that match the given CSS selector.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scroll({int? x, int? y}) → Future<void>
Scrolls this element in x and/or y direction by pixels.
override
scrollIntoView() → Future<void>
Scrolls this element into view.
override
testCreatorGetters() → String
Gives all getters that can be used by Test Creator.
override
testCreatorInvokeMethod(String methodName, List positionalArguments, [Map<Symbol, dynamic>? namedArguments]) → dynamic
(HTML only) Invoke a getter or a method.
testCreatorMethods() → String
Gives all unannotated methods that can be used by Test Creator.
override
toString() → String
A string representation of this object.
override
toStringDeep() → String
Gives a full description of the element for debugger.
override
type(String keys, {bool focusBefore = true, bool blurAfter = true}) → Future<Null>
Types keys into this element, if possible (e.g. for an input element).
override
typeSequence(PageLoaderKeyboard keys) → Future<void>
Sends all events defined by keys in the exact order they are configured.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited