HtmlPageUtils class

Support for PageUtils in HTML context.

Inheritance

Constructors

HtmlPageUtils({SyncFn externalSyncFn = noOpExecuteSyncedFn})

Properties

focused → HtmlPageLoaderElement
Gets the element on the DOM that currently has focus.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
mouse → PageLoaderMouse
Gets the mouse.
no setteroverride
pointer → PageLoaderPointer
Gets the pointer.
no setteroverride
root → HtmlPageLoaderElement
Gets the body for the current page.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncFn → SyncFn
final

Methods

byTag(String tag) → PageLoaderElement
Gets the current root element for the DOM.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited