WebDriverPageUtils class

Support for PageUtils in WebDriver context.

Inheritance

Constructors

WebDriverPageUtils(WebDriver driver)

Properties

driver → WebDriver
The underlying instance of WebDriver.
final
focused → WebDriverPageLoaderElement
Gets the element that currently has focus on the given page.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
mouse → WebDriverMouse
Gets the mouse.
no setteroverride
pointer → WebDriverPointer
Gets the pointer.
no setteroverride
root → WebDriverPageLoaderElement
Gets the root element for the given page.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

byTag(String tag) → WebDriverPageLoaderElement
Finds PageLoaderElement from this source by tag.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited